package com.esignlive.example;

import com.silanis.esl.sdk.Direction;
import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.PageRequest;

import static com.silanis.esl.sdk.builder.DocumentBuilder.newDocumentWithName;
import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;
import static com.silanis.esl.sdk.builder.SignerBuilder.newSignerWithEmail;

import java.util.Iterator;
import java.util.List;

public class creatingLayouts {

	// replace the API_KEY placeholder with your api key
	public static String API_KEY = "API_KEY";
	public static String API_URL = "https://sandbox.e-signlive.com/api";

	public static void main(String[] args) {

		EslClient eslClient = new EslClient(API_KEY, API_URL);
		
		/*-------------------------------------CREATE LAYOUT FROM PACKAGE-------------------------------------*/
		
		// Create your document package
		DocumentPackage myPackage = newPackageNamed("Layout Example Java SDK")
				.describedAs("This is a package with document to create layout.")
				.withSigner(newSignerWithEmail("john.doe@gmail.com")
						.withCustomId("Signer")
						.withFirstName("John")
						.withLastName("Doe")
						.withTitle("Salesman")
						.withCompany("BMW"))
				.withSigner(newSignerWithEmail("mary.doe@gmail.com")
						.withCustomId("Sender")
						.withFirstName("Mary")
						.withLastName("Doe")
						.withTitle("Senior Manager")
						.withCompany("Group Insurance Inc."))
				.withDocument(newDocumentWithName("My sample document")
						.withId("documentId")
						.withDescription("Layout document description")
						.fromFile("DOC_FILE_PATH")
						.enableExtraction())
				.build();

		PackageId packageId = eslClient.createPackage(myPackage);
		myPackage.setId(packageId);

		// Create layout from package
		String layoutId = eslClient.getLayoutService().createLayout(myPackage);
		System.out.println(layoutId);
		
		/*----------------------------------------------------------------------------------------------------*/
		
		/*---------------------------------------RETRIEVE YOUR LAYOUTS----------------------------------------*/

		
		// The first step is to retrieve the layouts from the first page. In my example, I chose to retrieve 5 layouts at a time but you can set this to any number.
		int i = 1;
		List<DocumentPackage> layouts = eslClient.getLayoutService().getLayouts(Direction.DESCENDING,
				new PageRequest(i, 5));
		// Next, you will create your iterator object. It will enable you to iterate through your list of layouts.
		while (!layouts.isEmpty()) {
			Iterator<DocumentPackage> index = layouts.iterator();
			while (index.hasNext()) {
				//This is where you retrieve your layout name and id.
				DocumentPackage myLayout = index.next();
				System.out.println(myLayout.getName() + " " + myLayout.getId());
				i++;
			}
			// Finally, you will retrieve your next 5 layouts from the second page and start over up until youve retrieved all your layouts.
			layouts = eslClient.getLayoutService().getLayouts(Direction.DESCENDING, new PageRequest(i, 5));

		}
		
		/*-----------------------------------------------------------------------------------------------------*/
		
		/*-----------------------------------------APPLY YOUR LAYOUT-------------------------------------------*/
		
		// Create a new package to apply document layout to
		DocumentPackage packageFromLayout = newPackageNamed("Document Layout Example Java SDK")
				.describedAs("This is a package created using the e-SignLive Java SDK")
				.withSigner(newSignerWithEmail("john.doe@gmail.com")
						.withCustomId("Signer")
						.withFirstName("John")
						.withLastName("Doe")
						.withTitle("Salesman")
						.withCompany("BMW"))
				.withSigner(newSignerWithEmail("mary.doe@gmail.com")
						.withCustomId("Sender")
						.withFirstName("Mary")
						.withLastName("Doe")
						.withTitle("Senior Manager")
						.withCompany("Group Insurance Inc."))
				.withDocument(newDocumentWithName("Apply Layout Document")
						.withId("documentId")
						.withDescription("Document with applied layout description.")
						.fromFile("DOC_FILE_PATH"))
				.build();

		PackageId packageId2 = eslClient.createPackage(packageFromLayout);

		// Apply the layout to document in package
		eslClient.getLayoutService().applyLayout(packageId2, "documentId", "f682c87b-d806-4120-a29e-0c76aadd9302");
		
		/*-----------------------------------------------------------------------------------------------------*/
	}
}
